==> Gambio v4.1.2.0.zip: Vollversion GX v4.1.2.0/Shopsystem/Dateien/lang/german/original_sections/admin/admin_index.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	admin_index.lang.inc.php 2015-01-02 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'BOX_CATALOG_MANUFACTURERS' => 'Hersteller',
	'BOX_CONFIGURATION_CACHE' => 'Cache Optionen',
	'BOX_CONFIGURATION_LOGGING' => 'Logging Informationen',
	'BOX_CONFIGURATION_MYSTORE' => 'Mein Shop',
	'BOX_CONNECTION_PROTECTED' => 'Sie sind gesichert durch eine %s sichere SSL Verbindung.',
	'BOX_CONNECTION_UNKNOWN' => 'unbekannt',
	'BOX_CONNECTION_UNPROTECTED' => 'Sie sind <font color="#ff0000">nicht</font> durch eine sichere SSL Verbindung gesichert.',
	'BOX_CUSTOMERS_ACCOUNTING' => 'Verrechnung',
	'BOX_CUSTOMERS_CUSTOMERS' => 'Kunden',
	'BOX_CUSTOMERS_ORDERS' => 'Bestellungen',
	'BOX_ENTRY_BUG_REPORTS' => 'Fehler Reporte',
	'BOX_ENTRY_CUSTOMERS' => 'Kunden:',
	'BOX_ENTRY_CVS_REPOSITORY' => 'CVS Repository',
	'BOX_ENTRY_FAQ' => 'Fragen und Antworten',
	'BOX_ENTRY_INFORMATION_PORTAL' => 'Informationsportal',
	'BOX_ENTRY_LIVE_DISCUSSIONS' => 'Live Diskussionen',
	'BOX_ENTRY_MAILING_LISTS' => 'Mailing Listen',
	'BOX_ENTRY_PRODUCTS' => 'Artikel:',
	'BOX_ENTRY_REVIEWS' => 'Bewertungen:',
	'BOX_ENTRY_SUPPORT_FORUMS' => 'Support Forum',
	'BOX_ENTRY_SUPPORT_SITE' => 'Support Seite',
	'BOX_HEADING_CONFIGURATION' => 'Konfiguration',
	'BOX_LOCALIZATION_CURRENCIES' => 'Währungen',
	'BOX_LOCALIZATION_LANGUAGES' => 'Sprachen',
	'BOX_MODULES_PAYMENT' => 'Zahlungsweise',
	'BOX_MODULES_SHIPPING' => 'Versandart',
	'BOX_TAXES_COUNTRIES' => 'Länder',
	'BOX_TAXES_GEO_ZONES' => 'Steuerzonen',
	'BOX_TITLE_ORDERS' => 'Bestellungen',
	'BOX_TITLE_STATISTICS' => 'Statistik',
	'CATALOG_CONTENTS' => 'Inhalt',
	'HEADING_TITLE' => 'Option wählen...',
	'REPORTS_ORDERS' => 'Bestellungen',
	'REPORTS_PRODUCTS' => 'Artikel',
	'TOOLS_BACKUP' => 'Datensicherung',
	'TOOLS_BANNERS' => 'Bannerverwaltung',
	'TOOLS_FILES' => 'Dateiverwaltung'
);

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/admin/admin_index.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	admin_index.lang.inc.php 2015-01-02 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'BOX_CATALOG_MANUFACTURERS' => 'Hersteller',
	'BOX_CONFIGURATION_CACHE' => 'Cache Optionen',
	'BOX_CONFIGURATION_LOGGING' => 'Logging Informationen',
	'BOX_CONFIGURATION_MYSTORE' => 'Mein Shop',
	'BOX_CONNECTION_PROTECTED' => 'Du bist durch eine %s sichere SSL Verbindung gesichert.',
	'BOX_CONNECTION_UNKNOWN' => 'unbekannt',
	'BOX_CONNECTION_UNPROTECTED' => 'Du bist <font color="#ff0000">nicht</font> durch eine sichere SSL Verbindung gesichert.',
	'BOX_CUSTOMERS_ACCOUNTING' => 'Verrechnung',
	'BOX_CUSTOMERS_CUSTOMERS' => 'Kunden',
	'BOX_CUSTOMERS_ORDERS' => 'Bestellungen',
	'BOX_ENTRY_BUG_REPORTS' => 'Fehler Reporte',
	'BOX_ENTRY_CUSTOMERS' => 'Kunden:',
	'BOX_ENTRY_CVS_REPOSITORY' => 'CVS Repository',
	'BOX_ENTRY_FAQ' => 'Fragen und Antworten',
	'BOX_ENTRY_INFORMATION_PORTAL' => 'Informationsportal',
	'BOX_ENTRY_LIVE_DISCUSSIONS' => 'Live Diskussionen',
	'BOX_ENTRY_MAILING_LISTS' => 'Mailing Listen',
	'BOX_ENTRY_PRODUCTS' => 'Artikel:',
	'BOX_ENTRY_REVIEWS' => 'Bewertungen:',
	'BOX_ENTRY_SUPPORT_FORUMS' => 'Support Forum',
	'BOX_ENTRY_SUPPORT_SITE' => 'Support Seite',
	'BOX_HEADING_CONFIGURATION' => 'Konfiguration',
	'BOX_LOCALIZATION_CURRENCIES' => 'Währungen',
	'BOX_LOCALIZATION_LANGUAGES' => 'Sprachen',
	'BOX_MODULES_PAYMENT' => 'Zahlungsweise',
	'BOX_MODULES_SHIPPING' => 'Versandart',
	'BOX_TAXES_COUNTRIES' => 'Länder',
	'BOX_TAXES_GEO_ZONES' => 'Steuerzonen',
	'BOX_TITLE_ORDERS' => 'Bestellungen',
	'BOX_TITLE_STATISTICS' => 'Statistik',
	'CATALOG_CONTENTS' => 'Inhalt',
	'HEADING_TITLE' => 'Option wählen...',
	'REPORTS_ORDERS' => 'Bestellungen',
	'REPORTS_PRODUCTS' => 'Artikel',
	'TOOLS_BACKUP' => 'Datensicherung',
	'TOOLS_BANNERS' => 'Bannerverwaltung',
	'TOOLS_FILES' => 'Dateiverwaltung'
);
